@@ -13,10 +13,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_fis.literals import ExperimentActionStatus, ExperimentStatus
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -93,21 +91,7 @@ ActionTypeDef = TypedDict(
 )
 
 ExperimentActionStateTypeDef = TypedDict(
-    "ExperimentActionStateTypeDef",
-    {
-        "status": Literal[
-            "pending",
-            "initiating",
-            "running",
-            "completed",
-            "cancelled",
-            "stopping",
-            "stopped",
-            "failed",
-        ],
-        "reason": str,
-    },
-    total=False,
+    "ExperimentActionStateTypeDef", {"status": ExperimentActionStatus, "reason": str}, total=False
 )
 
 ExperimentActionTypeDef = TypedDict(
@@ -124,14 +108,7 @@ ExperimentActionTypeDef = TypedDict(
 )
 
 ExperimentStateTypeDef = TypedDict(
-    "ExperimentStateTypeDef",
-    {
-        "status": Literal[
-            "pending", "initiating", "running", "completed", "stopping", "stopped", "failed"
-        ],
-        "reason": str,
-    },
-    total=False,
+    "ExperimentStateTypeDef", {"status": ExperimentStatus, "reason": str}, total=False
 )
 
 ExperimentStopConditionTypeDef = TypedDict(
